@@ -267,7 +267,7 @@ void Kanagram::paintEvent(TQPaintEvent *)
 		if(m_overAboutKDE)
 		{
 			p.drawPixmap(567, 213, *m_aboutKDEOverlay);
-			drawHelpText(p, i18n("About KDE"));
+			drawHelpText(p, i18n("About TDE"));
 		}
 		else
 			p.drawPixmap(567, 213, *m_aboutKDEOverlayOver);
