@@ -762,7 +762,7 @@ void Learn::qupdate()
 
 struct Learn::scoreCompare 
 {
-	bool operator()(const TQListViewItem* v1, const TQListViewItem* v2)
+	bool operator()(const TQListViewItem* v1, const TQListViewItem* v2) const
 	{
 		return v1->text(4).toInt() < v2->text(4).toInt();
 	}
