@@ -250,7 +250,7 @@ class MultipleChoice;
   * This class contains the expressions of your vocabulary
   ************************************************************/
 
-class kvoctrainDoc : public TQObject
+class KDE_EXPORT kvoctrainDoc : public TQObject
 {
   Q_OBJECT
   
